/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.inference.protegeowl;

import edu.stanford.smi.protege.event.ProjectAdapter;
import edu.stanford.smi.protege.event.ProjectEvent;
import edu.stanford.smi.protege.event.ProjectListener;
import edu.stanford.smi.protege.model.Project;
import edu.stanford.smi.protegex.owl.model.OWLModel;

import java.util.HashMap;
import java.util.Map;

/**
 * User: matthewhorridge<br>
 * The Univeristy Of Manchester<br>
 * Medical Informatics Group<br>
 * Date: Jun 22, 2004<br><br>
 * <p/>
 * matthew.horridge@cs.man.ac.uk<br>
 * www.cs.man.ac.uk/~horridgm<br><br>
 */
public class ReasonerManager {

    public Map reasonerMap;

    private static ReasonerManager instance;

    private ProjectListener projectListener = new ProjectAdapter() {
        public void projectClosed(ProjectEvent event) {
            Project project = (Project) event.getSource();
            project.removeProjectListener(this);
            reasonerMap.remove(project.getKnowledgeBase());
        }
    };


    private ReasonerManager() {
        reasonerMap = new HashMap();
    }


    public synchronized static ReasonerManager getInstance() {
        if (instance == null) {
            instance = new ReasonerManager();
        }

        return instance;
    }


    /**
     * Gets the reasoner for the specified knowledge base
     *
     * @param kb The <code>OWLModel</code>.
     * @return A reasoner to be used for reasoning over
     *         the specified knowledge base.
     */
    public ProtegeOWLReasoner getReasoner(OWLModel kb) {
        ProtegeOWLReasoner reasoner = (ProtegeOWLReasoner) reasonerMap.get(kb);

        if (reasoner == null) {
            reasoner = new DefaultProtegeOWLReasoner(kb);

            reasonerMap.put(kb, reasoner);
            kb.getProject().addProjectListener(projectListener);
        }

        return reasoner;
    }


    /**
     * @deprecated The <code>createReasoner</code> method should be used instead.
     */
    public ProtegeOWLReasoner getReasoner(OWLModel kb, boolean createNew) {
        return new DefaultProtegeOWLReasoner(kb);
    }


    public ProtegeOWLReasoner createReasoner(OWLModel model) {
        return new DefaultProtegeOWLReasoner(model);
    }
}

