/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */


package edu.stanford.smi.protegex.owl.swrl.bridge.query;

import edu.stanford.smi.protegex.owl.swrl.bridge.query.exceptions.ResultException;

import java.util.List;

/**
 ** Interface to configure a result and add data to it. See the Result class for detailed comments.
 */
public interface ResultGenerator
{
  static String MinAggregateFunction = "min"; 
  static String MaxAggregateFunction = "max"; 
  static String SumAggregateFunction = "sum"; 
  static String AvgAggregateFunction = "avg"; 
  static String CountAggregateFunction = "count"; 
  
  void initialize();
  
  void addColumns(List<String> columnNames) throws ResultException;
  void addColumn(String columnName) throws ResultException;

  void addAggregateColumn(String columnName, String aggregateFunctionName) throws ResultException;
  void addOrderByColumn(int orderedColumnIndex, boolean ascending) throws ResultException;
  
  boolean isOrdered();
  boolean isAscending();
  
  void setIsDistinct();
  void addColumnDisplayName(String columnName) throws ResultException;
  
  boolean isConfigured();
  void configured() throws ResultException;
  
  void addRow(List<ResultValue> resultValues) throws ResultException;
  void openRow() throws ResultException;
  void addRowData(ResultValue value) throws ResultException;
  void closeRow() throws ResultException;
  
  boolean isRowOpen();
  boolean isPrepared();
  void prepared() throws ResultException;
} // ResultGenerator
