/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.ui.cls;

import edu.stanford.smi.protegex.owl.model.*;
import edu.stanford.smi.protegex.owl.ui.actions.ResourceAction;
import edu.stanford.smi.protegex.owl.ui.icons.OWLIcons;
import edu.stanford.smi.protegex.owl.ui.resourcedisplay.ResourceDisplay;
import edu.stanford.smi.protegex.owl.ui.widget.OWLUI;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

/**
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public class ConvertToDefinedClassAction extends ResourceAction {

    public ConvertToDefinedClassAction() {
        super("Convert to defined class",
                OWLIcons.getImageIcon(OWLIcons.DEFINED_OWL_CLASS),
                AddSubclassAction.GROUP, true);
    }


    public void actionPerformed(ActionEvent e) {
        try {
            final OWLNamedClass cls = (OWLNamedClass) getResource();
            getOWLModel().beginTransaction("Convert " + cls.getBrowserText() + " to defined class", (cls == null ? null : cls.getName()));
            performAction(cls);
            getOWLModel().commitTransaction();
        }
        catch (Exception ex) {
        	getOWLModel().rollbackTransaction();
            OWLUI.handleError(getOWLModel(), ex);
        }
    }


    public boolean isSuitable(Component component, RDFResource resource) {
        return component instanceof ResourceDisplay &&
                resource instanceof OWLNamedClass &&
                resource.isEditable() &&
                ((OWLNamedClass) resource).getDefinition() == null;
    }


    public static void performAction(OWLNamedClass namedClass) {
        OWLModel owlModel = namedClass.getOWLModel();
        Collection superclasses = new ArrayList(namedClass.getSuperclasses(false));
        superclasses.remove(namedClass.getOWLModel().getOWLThingClass());
        if (superclasses.size() == 1) {
            RDFSClass superclass = (RDFSClass) superclasses.iterator().next();
            superclass.addSuperclass(namedClass);
        }
        else if (superclasses.size() > 1) {
            OWLIntersectionClass intersectionCls = owlModel.createOWLIntersectionClass();
            for (Iterator it = superclasses.iterator(); it.hasNext();) {
                RDFSClass superClass = (RDFSClass) it.next();
                intersectionCls.addOperand(superClass.createClone());
            }
            namedClass.setDefinition(intersectionCls);
            for (Iterator it = superclasses.iterator(); it.hasNext();) {
                RDFSClass superClass = (RDFSClass) it.next();
                if (superClass instanceof OWLAnonymousClass) {
                    superClass.delete();
                }
            }
        }
    }
}
