/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.ui.metadatatab;

import edu.stanford.smi.protege.util.Wizard;
import edu.stanford.smi.protege.util.WizardPage;
import edu.stanford.smi.protegex.owl.jena.OWLFilesPlugin;
import edu.stanford.smi.protegex.owl.ui.profiles.ProfileSelectionWizardPage;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.*;

/**
 * User: matthewhorridge<br>
 * The University Of Manchester<br>
 * Medical Informatics Group<br>
 * Date: Sep 27, 2005<br><br>
 * <p/>
 * matthew.horridge@cs.man.ac.uk<br>
 * www.cs.man.ac.uk/~horridgm<br><br>
 */
public class OntologyURIWizardPage extends WizardPage {

    private OWLFilesPlugin plugin;

    private OntologyURIPanel ontologyURIPanel;


    public OntologyURIWizardPage(Wizard wizard, OWLFilesPlugin plugin) {
        super("Ontology URI Page", wizard);
        this.plugin = plugin;
        createUI();
    }


    private void createUI() {
        setLayout(new BorderLayout());
        add(ontologyURIPanel = new OntologyURIPanel(true, true));
        ontologyURIPanel.addChangeListener(new ChangeListener() {
            public void stateChanged(ChangeEvent e) {
                setPageComplete(ontologyURIPanel.getOntologyURI() != null);
            }
        });
        setPageComplete(ontologyURIPanel.getOntologyURI() != null);
    }


    public void onFinish() {
        if (plugin != null) {
            // Actually setting the default namespace
            // sets the name of the ontology!
            String defaultNamespace = ontologyURIPanel.getOntologyURI() + "#";
            plugin.setDefaultNamespace(defaultNamespace);
        }
    }


    public WizardPage getNextPage() {
        return new ProfileSelectionWizardPage(getWizard(), plugin);
    }
}

